@@ -2,7 +2,7 @@ package Test2::Harness::UI::Sweeper;
 use strict;
 use warnings;
 
-our $VERSION = '0.000127';
+our $VERSION = '0.000128';
 
 use Test2::Harness::UI::Util::HashBase qw{
     <config
@@ -66,14 +66,18 @@ sub sweep {
 
                     my $has_binary = $job->events->search({has_binary => 1});
                     while (my $e = $has_binary->next()) {
-                        $has_binary->binaries->delete;
-                        $e->Delete;
+                        $e->binaries->delete;
+                        $e->delete;
                     }
 
                     $job->events->delete;
                 }
                 else {
-                    $job->events->search({'-not' => {is_subtest => 1, nested => 0}})->delete;
+                    my $events = $job->events->search({'-not' => {is_subtest => 1, nested => 0}});
+                    while (my $e = $events->next()) {
+                        $e->binaries->delete;
+                        $e->delete;
+                    }
                 }
             }
 
